#
# spec file for package opensaml
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pkgdocdir %{_docdir}/%{name}
Name:           opensaml
Version:        2.6.1
Release:        lp150.1.9
Summary:        Security Assertion Markup Language library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            http://www.opensaml.org/
Source0:        https://shibboleth.net/downloads/c++-opensaml/%{version}/%{name}-%{version}.tar.bz2
Source1:        https://shibboleth.net/downloads/c++-opensaml/%{version}/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Patch0:         opensaml-2.5.5-doxygen_timestamp.patch
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  liblog4shib-devel >= 1.0.4
BuildRequires:  libxerces-c-devel >= 3.1
BuildRequires:  libxml-security-c-devel >= 1.7.3
BuildRequires:  libxmltooling-devel >= 1.6.0
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel >= 1.32.0
%endif

%description
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

%package -n opensaml-bin
Summary:        Utilities for OpenSAML library
Group:          Development/Libraries/C and C++

%description -n opensaml-bin
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

This package contains the utility programs.

%package -n libsaml9
Summary:        Security Assertion Markup Language library
Group:          System/Libraries
Provides:       opensaml = %{version}-%{release}
Obsoletes:      opensaml < %{version}-%{release}

%description -n libsaml9
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

This package contains just the shared library.

%package -n libsaml-devel
Summary:        OpenSAML development Headers
Group:          Development/Libraries/C and C++
Requires:       liblog4shib-devel >= 1.0.4
Requires:       libsaml9 = %{version}-%{release}
Requires:       libxerces-c-devel >= 3.1
Requires:       libxml-security-c-devel >= 1.7.3
Requires:       libxmltooling-devel >= 1.6.0
Provides:       opensaml-devel = %{version}-%{release}
Obsoletes:      opensaml-devel < %{version}-%{release}

%description -n libsaml-devel
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

This package includes files needed for development with OpenSAML.

%package -n opensaml-schemas
Summary:        OpenSAML schemas and catalog
Group:          Development/Libraries/C and C++

%description -n opensaml-schemas
OpenSAML is an open source implementation of the OASIS Security Assertion
Markup Language Specification. It contains a set of open source C++ classes
that support the SAML 1.0, 1.1, and 2.0 specifications.

This package includes XML schemas and related files.

%prep
%setup -q
%patch0 -p1

%build
%configure
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} pkgdocdir=%{pkgdocdir}
# Don't package unit tester if present.
rm -f %{buildroot}/%{_bindir}/samltest

%check
make %{?_smp_mflags} check

%post -n libsaml9 -p /sbin/ldconfig
%postun -n libsaml9 -p /sbin/ldconfig

%files -n opensaml-bin
%{_bindir}/samlsign

%files -n libsaml9
%{_libdir}/libsaml.so.*

%files -n opensaml-schemas
%dir %{_datadir}/xml/opensaml
%{_datadir}/xml/opensaml/*

%files -n libsaml-devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/opensaml.pc
%doc %{pkgdocdir}

%changelog
* Wed Nov 15 2017 kstreitova@suse.com
- update to 2.6.1
  * [CPPOST-99] - DynamicMetadataProvider rejects metadata returned
    from MDQ associated with artifact profile
  * [CPPOST-100] - Assertions20SchemaValidator fails in case of
    EncryptedAttribute in Assertions
  * [CPPOST-105] - Dynamic metadata provider fails to install filt
  * fixes [bsc#1068685] [CVE-2017-16853]
* Thu Sep 21 2017 kstreitova@suse.com
- update to 2.6.0
  * [CPPOST-10] - Name Format Constants for Unspecified Are
    Misspelled
  * [CPPOST-85] - Dynamic metadata plugin race conditons / leaks
  * [CPPOST-93] - Source build fails to link properly against
    OpenSSL
  * [CPPOST-95] - Add MD RPI extension implementation to metadata
    classes.
  * [CPPOST-96] - EntityMatcher implementation based on RPI
    registrationAuthority extension
  * [CPPOST-97] - skip signature check on cached copy of verified
    metadata at restart
- now opensaml requires libxmltooling-devel >= 1.6.0
- update soname for libsaml from 8 to 9
- use https instead of http in Source
- run spec-cleaner
* Sat Feb 11 2017 jengelh@inai.de
- Update RPM groups and summary
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Aug  5 2015 mpluskal@suse.com
- Add gpg signature
* Tue Jul 28 2015 kstreitova@suse.com
- use spec-cleaner again
- fix Source address
- remove unused conditionals
* Mon Jul 27 2015 kstreitova@suse.com
- use spec-cleaner
- package cleaning
- add opensaml-2.5.5-doxygen_timestamp.patch to remove timestamps
  in a documentation generated by Doxygen and avoid RPMLINT warnings
  (file-contains-date-and-time).
* Fri Jul 24 2015 kstreitova@suse.com
- initial revision
